package com.sundot.airport.system.service;

import java.util.List;

import com.sundot.airport.system.domain.BaseCheckPoint;

/**
 * 检查部位Service接口
 *
 * @author ruoyi
 * @date 2025-07-08
 */
public interface IBaseCheckPointService {
    /**
     * 查询检查部位
     *
     * @param id 检查部位主键
     * @return 检查部位
     */
    public BaseCheckPoint selectBaseCheckPointById(Long id);

    /**
     * 查询检查部位列表
     *
     * @param baseCheckPoint 检查部位
     * @return 检查部位集合
     */
    public List<BaseCheckPoint> selectBaseCheckPointList(BaseCheckPoint baseCheckPoint);

    /**
     * 新增检查部位
     *
     * @param baseCheckPoint 检查部位
     * @return 结果
     */
    public int insertBaseCheckPoint(BaseCheckPoint baseCheckPoint);

    /**
     * 修改检查部位
     *
     * @param baseCheckPoint 检查部位
     * @return 结果
     */
    public int updateBaseCheckPoint(BaseCheckPoint baseCheckPoint);

    /**
     * 批量删除检查部位
     *
     * @param ids 需要删除的检查部位主键集合
     * @return 结果
     */
    public int deleteBaseCheckPointByIds(Long[] ids);

    /**
     * 删除检查部位信息
     *
     * @param id 检查部位主键
     * @return 结果
     */
    public int deleteBaseCheckPointById(Long id);

    /**
     * 查询检查部位列表树形结构
     *
     * @param baseCheckPoint 检查部位
     * @return 树结构列表
     */
    public List<BaseCheckPoint> selectBaseCheckPointListTree(BaseCheckPoint baseCheckPoint);

    /**
     * 构建前端所需要树结构
     *
     * @param list 列表
     * @return 树结构列表
     */
    public List<BaseCheckPoint> buildTree(List<BaseCheckPoint> list);
}
